@@ -42,6 +42,12 @@ module Data.Yaml
     , (.:)
     , (.:?)
     , (.!=)
+      -- ** With helpers (since 0.8.23)
+    , withObject
+    , withText
+    , withArray
+    , withScientific
+    , withBool
       -- * Parsing
     , parseMonad
     , parseEither
@@ -70,6 +76,7 @@ import Data.Aeson
     ( Value (..), ToJSON (..), FromJSON (..), object
     , (.=) , (.:) , (.:?) , (.!=)
     , Object, Array
+    , withObject, withText, withArray, withScientific, withBool
     )
 import Data.Aeson.Encode (encodeToTextBuilder)
 import Data.Aeson.Types (Pair, parseMaybe, parseEither, Parser)
